@@ -262,6 +262,8 @@ def inverse(a):
     >>> inverse(a)
     [[1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]]
     """
+    coord = Matrix(a).get_element    
+
     def adj():
         adj_matrix = matrix()
 
@@ -273,6 +275,14 @@ def inverse(a):
         
         return Matrix(adj_matrix).transpose()
             
+    if Matrix(a).dim("rows") == 2 and Matrix(a).dim("cols") == 2:
+        div = 1 / determinant(a)
+        pre_inverse = matrix(
+            row(coord(2, 2), -1*coord(1, 2)),
+            row(-1*coord(2, 1), -1*coord(1, 1))
+            )
+        return MatOperators().scalar_mul(pre_inverse, div)
+
     adj_matrix = adj()
     div = 1 / determinant(a)
 
